==> net.bluemind.p2.we.settings-5.4.2760.zip: net/bluemind/system/api/gwt/endpoint/InternalCredentialsSockJsEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.system.api.gwt.endpoint;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.http.client.URL;
import com.google.gwt.json.client.JSONValue;
import com.google.gwt.json.client.JSONObject;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.lang.Long;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.Stream;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;
import net.bluemind.restbus.api.gwt.AsyncHandlerAdapter;
import net.bluemind.restbus.api.gwt.GwtRestRequest;
import net.bluemind.restbus.api.gwt.GwtRestResponse;
import net.bluemind.restbus.api.gwt.RestBusImpl;

public class InternalCredentialsSockJsEndpoint implements net.bluemind.system.api.IInternalCredentialsAsync {

	private String rootUri = "/api";

	private String baseUri;

    private String sessionId;

	public InternalCredentialsSockJsEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/credentials/{domainUid}";
		this.sessionId = sessionId;
	
		uri_ = uri_.replace("{domainUid}", URL.encodePathSegment(pathVars[0]));
		
		baseUri = uri_;
	}

	public InternalCredentialsSockJsEndpoint withRoot(String root) {
		this.rootUri = root;
		return this;
	}

	@Override
	public void addUserCredential(String userUid, net.bluemind.system.api.Credential credential, final AsyncHandler<Void> handler) {
		String postUri = "/user/{userUid}";

		postUri = postUri.replace("{userUid}", URL.encodePathSegment(""+userUid));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.gwt.serder.CredentialGwtSerDer().serialize( credential);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}


	@Override
	public void addUserCredentials(String userUid, List<net.bluemind.system.api.Credential> credentials, final AsyncHandler<Void> handler) {
		String postUri = "/user/{userUid}/_credentials";

		postUri = postUri.replace("{userUid}", URL.encodePathSegment(""+userUid));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.gwt.serder.CredentialGwtSerDer()).serialize( credentials);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}


	@Override
	public void getDomainCredentialById(String credentialId, final AsyncHandler<String> handler) {
		String postUri = "/{credentialId}";

		postUri = postUri.replace("{credentialId}", URL.encodePathSegment(""+credentialId));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<String>(handler) {
					@Override
			protected String handleResponse(
							JSONValue jsonValue) {
				return GwtSerDerUtils.STRING.deserialize( jsonValue );
			}
		});

	}


	@Override
	public void getObfuscatedUserCredentials(String userUid, final AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.system.api.Credential>> handler) {
		String postUri = "/user/{userUid}";

		postUri = postUri.replace("{userUid}", URL.encodePathSegment(""+userUid));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.core.api.ListResult<net.bluemind.system.api.Credential>>(handler) {
					@Override
			protected net.bluemind.core.api.ListResult<net.bluemind.system.api.Credential> handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.core.api.gwt.serder.ListResultGwtSerDer<>(new net.bluemind.system.api.gwt.serder.CredentialGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void getUserCredentials(String userUid, final AsyncHandler<List<net.bluemind.system.api.Credential>> handler) {
		String postUri = "/user/{userUid}/plain";

		postUri = postUri.replace("{userUid}", URL.encodePathSegment(""+userUid));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<List<net.bluemind.system.api.Credential>>(handler) {
					@Override
			protected List<net.bluemind.system.api.Credential> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.gwt.serder.CredentialGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void removeUserCredential(String userUid, String credentialId, final AsyncHandler<Void> handler) {
		String postUri = "/user/{userUid}/{credentialId}";

		postUri = postUri.replace("{userUid}", URL.encodePathSegment(""+userUid));
		postUri = postUri.replace("{credentialId}", URL.encodePathSegment(""+credentialId));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"DELETE",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}

	public net.bluemind.system.api.IInternalCredentialsPromise promiseApi() {
		return new InternalCredentialsEndpointPromise(this);
	}

}

==> net.bluemind.p2.we.settings-5.5.3184.zip: net/bluemind/system/api/gwt/endpoint/InternalCredentialsSockJsEndpoint.java <==
/* BEGIN LICENSE
 * Copyright Â© Blue Mind SAS, 2012-2016
 *
 * This file is part of BlueMind. BlueMind is a messaging and collaborative
 * solution.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of either the GNU Affero General Public License as
 * published by the Free Software Foundation (version 3 of the License).
 *
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * See LICENSE.txt
 * END LICENSE
 */
package net.bluemind.system.api.gwt.endpoint;

import com.google.gwt.core.client.JavaScriptObject;
import com.google.gwt.http.client.URL;
import com.google.gwt.json.client.JSONValue;
import com.google.gwt.json.client.JSONObject;

import java.util.List;
import java.util.Map;
import java.util.Set;
import java.lang.Long;

import net.bluemind.core.api.AsyncHandler;
import net.bluemind.core.api.Stream;
import net.bluemind.core.commons.gwt.EndpointRequestCallback;
import net.bluemind.core.commons.gwt.GwtSerDerUtils;
import net.bluemind.restbus.api.gwt.AsyncHandlerAdapter;
import net.bluemind.restbus.api.gwt.GwtRestRequest;
import net.bluemind.restbus.api.gwt.GwtRestResponse;
import net.bluemind.restbus.api.gwt.RestBusImpl;

public class InternalCredentialsSockJsEndpoint implements net.bluemind.system.api.IInternalCredentialsAsync {

	private String rootUri = "/api";

	private String baseUri;

    private String sessionId;

	public InternalCredentialsSockJsEndpoint(String sessionId, String... pathVars) {
		String uri_ = "/credentials/{domainUid}";
		this.sessionId = sessionId;
	
		uri_ = uri_.replace("{domainUid}", URL.encodePathSegment(pathVars[0]));
		
		baseUri = uri_;
	}

	public InternalCredentialsSockJsEndpoint withRoot(String root) {
		this.rootUri = root;
		return this;
	}

	@Override
	public void addTotpCredential(net.bluemind.system.api.TotpCredential totpCredential, final AsyncHandler<String> handler) {
		String postUri = "/user/totp";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.gwt.serder.TotpCredentialGwtSerDer().serialize( totpCredential);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<String>(handler) {
					@Override
			protected String handleResponse(
							JSONValue jsonValue) {
				return GwtSerDerUtils.STRING.deserialize( jsonValue );
			}
		});

	}


	@Override
	public void addUserCredential(String userUid, net.bluemind.system.api.Credential credential, final AsyncHandler<Void> handler) {
		String postUri = "/user/{userUid}";

		postUri = postUri.replace("{userUid}", URL.encodePathSegment(""+userUid));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.gwt.serder.CredentialGwtSerDer().serialize( credential);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}


	@Override
	public void addUserCredentials(String userUid, List<net.bluemind.system.api.Credential> credentials, final AsyncHandler<Void> handler) {
		String postUri = "/user/{userUid}/_credentials";

		postUri = postUri.replace("{userUid}", URL.encodePathSegment(""+userUid));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.gwt.serder.CredentialGwtSerDer()).serialize( credentials);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"PUT",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}


	@Override
	public void getDomainCredentialById(String credentialId, final AsyncHandler<String> handler) {
		String postUri = "/{credentialId}";

		postUri = postUri.replace("{credentialId}", URL.encodePathSegment(""+credentialId));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<String>(handler) {
					@Override
			protected String handleResponse(
							JSONValue jsonValue) {
				return GwtSerDerUtils.STRING.deserialize( jsonValue );
			}
		});

	}


	@Override
	public void getObfuscatedUserCredentials(String userUid, final AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.system.api.Credential>> handler) {
		String postUri = "/user/{userUid}";

		postUri = postUri.replace("{userUid}", URL.encodePathSegment(""+userUid));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.core.api.ListResult<net.bluemind.system.api.Credential>>(handler) {
					@Override
			protected net.bluemind.core.api.ListResult<net.bluemind.system.api.Credential> handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.core.api.gwt.serder.ListResultGwtSerDer<>(new net.bluemind.system.api.gwt.serder.CredentialGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void getSelfObfuscatedCredentials(final AsyncHandler<net.bluemind.core.api.ListResult<net.bluemind.system.api.Credential>> handler) {
		String postUri = "/user/_credentials/_self";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<net.bluemind.core.api.ListResult<net.bluemind.system.api.Credential>>(handler) {
					@Override
			protected net.bluemind.core.api.ListResult<net.bluemind.system.api.Credential> handleResponse(
							JSONValue jsonValue) {
				return new net.bluemind.core.api.gwt.serder.ListResultGwtSerDer<>(new net.bluemind.system.api.gwt.serder.CredentialGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void getUserCredentials(String userUid, final AsyncHandler<List<net.bluemind.system.api.Credential>> handler) {
		String postUri = "/user/{userUid}/plain";

		postUri = postUri.replace("{userUid}", URL.encodePathSegment(""+userUid));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"GET",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<List<net.bluemind.system.api.Credential>>(handler) {
					@Override
			protected List<net.bluemind.system.api.Credential> handleResponse(
							JSONValue jsonValue) {
				return new GwtSerDerUtils.ListSerDer<>(new net.bluemind.system.api.gwt.serder.CredentialGwtSerDer()).deserialize( jsonValue );
			}
		});

	}


	@Override
	public void removeSelfCredential(String credentialId, final AsyncHandler<Void> handler) {
		String postUri = "/user/_credentials/{credentialId}/_self";

		postUri = postUri.replace("{credentialId}", URL.encodePathSegment(""+credentialId));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"DELETE",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}


	@Override
	public void removeUserCredential(String userUid, String credentialId, final AsyncHandler<Void> handler) {
		String postUri = "/user/{userUid}/{credentialId}";

		postUri = postUri.replace("{userUid}", URL.encodePathSegment(""+userUid));
		postUri = postUri.replace("{credentialId}", URL.encodePathSegment(""+credentialId));
		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"DELETE",rootUri + uri_,params, bodyContent);
		
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Void>(handler) {
					@Override
			protected Void handleResponse(
							JSONValue jsonValue) {
				return null;
			}
		});

	}


	@Override
	public void validateTotpCredential(net.bluemind.system.api.TotpCredential totpCredential, final AsyncHandler<Boolean> handler) {
		String postUri = "/user/totp/validate";

		String uri_ = baseUri + postUri;

		Map<String,String> params = new java.util.HashMap<>();
		JavaScriptObject bodyContent = null;
		JSONValue jsonValue = new net.bluemind.system.api.gwt.serder.TotpCredentialGwtSerDer().serialize( totpCredential);
		if( jsonValue != null) {
			bodyContent = jsonValue.isObject().getJavaScriptObject();
		}

		 GwtRestRequest request = net.bluemind.restbus.api.gwt.GwtRestRequest.create(sessionId,"POST",rootUri + uri_,params, bodyContent);
		
		request.getHeaders().put("Accept", "application/json");
		RestBusImpl.get().sendMessage(request, new AsyncHandlerAdapter<Boolean>(handler) {
					@Override
			protected Boolean handleResponse(
							JSONValue jsonValue) {
				return GwtSerDerUtils.BOOLEAN.deserialize( jsonValue );
			}
		});

	}

	public net.bluemind.system.api.IInternalCredentialsPromise promiseApi() {
		return new InternalCredentialsEndpointPromise(this);
	}

}
